/*===========================================================================*/
/*   (Ieee/equiv.scm)                                                        */
/*   Bigloo (2.6b)                                                           */
/*   Inria -- Sophia Antipolis (c)       Mon Dec 15 12:14:36 CET 2003        */
/*===========================================================================*/
/* COMPILATION: (/users/serrano/prgm/project/bigloo/bin/bigloo -O4 -mklib -cc gcc-2.95 -fsharing -q -s -copt -DBGL_NO_PIC -unsafe -c Ieee/equiv.scm -indent -o objs/obj_u/Ieee/equiv.c)*/
/* GC selection */
#define THE_GC BOEHM_GC

#include <bigloo.h>
#include <signal.h>


/* Object type definitions */

extern bool_t BGl_2zd3zd3zz__r4_numbers_6_5z00(obj_t, obj_t);
BGL_EXPORTED_DECL obj_t BGl_modulezd2initializa7ationz75zz__r4_equivalence_6_2z00(long, char *);
extern obj_t BGl_modulezd2initializa7ationz75zz__errorz00(long, char *);
static obj_t BGl_methodzd2initzd2zz__r4_equivalence_6_2z00();
static obj_t BGl__equalzf3zf3zz__r4_equivalence_6_2z00(obj_t, obj_t, obj_t);
BGL_EXPORTED_DECL bool_t BGl_eqzf3zf3zz__r4_equivalence_6_2z00(obj_t, obj_t);
extern bool_t bigloo_strcmp(obj_t, obj_t);
extern long bgl_date_to_seconds(obj_t);
extern bool_t ucs2_strcmp(obj_t, obj_t);
static obj_t BGl_importedzd2moduleszd2initz00zz__r4_equivalence_6_2z00();
static obj_t BGl__eqvzf3zf3zz__r4_equivalence_6_2z00(obj_t, obj_t, obj_t);
static obj_t BGl_requirezd2initializa7ationz75zz__r4_equivalence_6_2z00 = BUNSPEC;
BGL_EXPORTED_DECL bool_t BGl_equalzf3zf3zz__r4_equivalence_6_2z00(obj_t, obj_t);
static obj_t BGl__eqzf3zf3zz__r4_equivalence_6_2z00(obj_t, obj_t, obj_t);
BGL_EXPORTED_DECL bool_t BGl_eqvzf3zf3zz__r4_equivalence_6_2z00(obj_t, obj_t);
extern bool_t BGl_objectzd2equalzf3z21zz__objectz00(BgL_objectz00_bglt, BgL_objectz00_bglt);
static obj_t *__cnst;


DEFINE_EXPORT_PROCEDURE( BGl_eqvzf3zd2envz21zz__r4_equivalence_6_2z00, BgL_bgl__eqvza7f3za7f3za7za7__r4_equivalence_6_2za7002074za7, BGl__eqvzf3zf3zz__r4_equivalence_6_2z00, 0L, 2 );
DEFINE_EXPORT_PROCEDURE( BGl_equalzf3zd2envz21zz__r4_equivalence_6_2z00, BgL_bgl__equalza7f3za7f3za7za7__r4_equivalence_6_2za7002075za7, BGl__equalzf3zf3zz__r4_equivalence_6_2z00, 0L, 2 );
DEFINE_EXPORT_PROCEDURE( BGl_eqzf3zd2envz21zz__r4_equivalence_6_2z00, BgL_bgl__eqza7f3za7f3za7za7__r4_equivalence_6_2za7002076za7, BGl__eqzf3zf3zz__r4_equivalence_6_2z00, 0L, 2 );



/* module-initialization */
BGL_EXPORTED_DEF obj_t BGl_modulezd2initializa7ationz75zz__r4_equivalence_6_2z00(long BgL_checksumz00_908, char * BgL_fromz00_909)
{ AN_OBJECT;
{ 
if(
CBOOL(BGl_requirezd2initializa7ationz75zz__r4_equivalence_6_2z00))
{ 
BGl_requirezd2initializa7ationz75zz__r4_equivalence_6_2z00 = 
BBOOL(((bool_t)0)); 
BGl_importedzd2moduleszd2initz00zz__r4_equivalence_6_2z00(); 
return BUNSPEC;}  else 
{ 
return BUNSPEC;} } 
}



/* eq? */
BGL_EXPORTED_DEF bool_t BGl_eqzf3zf3zz__r4_equivalence_6_2z00(obj_t BgL_obj1z00_1, obj_t BgL_obj2z00_2)
{ AN_OBJECT;
{ /* ./Ieee/equiv.scm 61 */
return 
(BgL_obj1z00_1==BgL_obj2z00_2);} 
}



/* _eq? */
obj_t BGl__eqzf3zf3zz__r4_equivalence_6_2z00(obj_t BgL_envz00_897, obj_t BgL_obj1z00_898, obj_t BgL_obj2z00_899)
{ AN_OBJECT;
{ /* ./Ieee/equiv.scm 61 */
{ /* ./Ieee/equiv.scm 62 */
bool_t BgL_auxz00_915;
BgL_auxz00_915 = 
(BgL_obj1z00_898==BgL_obj2z00_899); 
return 
BBOOL(BgL_auxz00_915);} } 
}



/* eqv? */
BGL_EXPORTED_DEF bool_t BGl_eqvzf3zf3zz__r4_equivalence_6_2z00(obj_t BgL_obj1z00_3, obj_t BgL_obj2z00_4)
{ AN_OBJECT;
{ /* ./Ieee/equiv.scm 67 */
if(
(BgL_obj1z00_3==BgL_obj2z00_4))
{ /* ./Ieee/equiv.scm 69 */
return ((bool_t)1);}  else 
{ /* ./Ieee/equiv.scm 69 */
if(
INTEGERP(BgL_obj1z00_3))
{ /* ./Ieee/equiv.scm 71 */
if(
INTEGERP(BgL_obj2z00_4))
{ /* ./Ieee/equiv.scm 72 */
return 
BGl_2zd3zd3zz__r4_numbers_6_5z00(BgL_obj1z00_3, BgL_obj2z00_4);}  else 
{ /* ./Ieee/equiv.scm 72 */
return ((bool_t)0);} }  else 
{ /* ./Ieee/equiv.scm 71 */
if(
REALP(BgL_obj1z00_3))
{ /* ./Ieee/equiv.scm 74 */
if(
REALP(BgL_obj2z00_4))
{ /* ./Ieee/equiv.scm 75 */
return 
BGl_2zd3zd3zz__r4_numbers_6_5z00(BgL_obj1z00_3, BgL_obj2z00_4);}  else 
{ /* ./Ieee/equiv.scm 75 */
return ((bool_t)0);} }  else 
{ /* ./Ieee/equiv.scm 74 */
if(
SYMBOLP(BgL_obj1z00_3))
{ /* ./Ieee/equiv.scm 77 */
if(
SYMBOLP(BgL_obj2z00_4))
{ /* ./Ieee/equiv.scm 79 */
obj_t BgL_arg1047z00_468;obj_t BgL_arg1048z00_469;
BgL_arg1047z00_468 = 
SYMBOL_TO_STRING(BgL_obj1z00_3); 
BgL_arg1048z00_469 = 
SYMBOL_TO_STRING(BgL_obj2z00_4); 
return 
bigloo_strcmp(BgL_arg1047z00_468, BgL_arg1048z00_469);}  else 
{ /* ./Ieee/equiv.scm 78 */
return ((bool_t)0);} }  else 
{ /* ./Ieee/equiv.scm 77 */
if(
FOREIGNP(BgL_obj1z00_3))
{ /* ./Ieee/equiv.scm 81 */
if(
FOREIGNP(BgL_obj2z00_4))
{ /* ./Ieee/equiv.scm 82 */
return 
FOREIGN_EQP(BgL_obj1z00_3, BgL_obj2z00_4);}  else 
{ /* ./Ieee/equiv.scm 82 */
return ((bool_t)0);} }  else 
{ /* ./Ieee/equiv.scm 81 */
return ((bool_t)0);} } } } } } 
}



/* _eqv? */
obj_t BGl__eqvzf3zf3zz__r4_equivalence_6_2z00(obj_t BgL_envz00_900, obj_t BgL_obj1z00_901, obj_t BgL_obj2z00_902)
{ AN_OBJECT;
{ /* ./Ieee/equiv.scm 67 */
{ /* ./Ieee/equiv.scm 69 */
bool_t BgL_auxz00_942;
BgL_auxz00_942 = 
BGl_eqvzf3zf3zz__r4_equivalence_6_2z00(BgL_obj1z00_901, BgL_obj2z00_902); 
return 
BBOOL(BgL_auxz00_942);} } 
}



/* equal? */
BGL_EXPORTED_DEF bool_t BGl_equalzf3zf3zz__r4_equivalence_6_2z00(obj_t BgL_obj1z00_5, obj_t BgL_obj2z00_6)
{ AN_OBJECT;
{ /* ./Ieee/equiv.scm 90 */
BGl_equalzf3zf3zz__r4_equivalence_6_2z00:
if(
(BgL_obj1z00_5==BgL_obj2z00_6))
{ /* ./Ieee/equiv.scm 92 */
return ((bool_t)1);}  else 
{ /* ./Ieee/equiv.scm 94 */
bool_t BgL_test1062z00_473;
BgL_test1062z00_473 = 
INTEGERP(BgL_obj1z00_5); 
if(BgL_test1062z00_473)
{ /* ./Ieee/equiv.scm 94 */
if(
INTEGERP(BgL_obj2z00_6))
{ /* ./Ieee/equiv.scm 96 */
long BgL_auxz00_953;long BgL_auxz00_951;
BgL_auxz00_953 = 
(long)CINT(BgL_obj2z00_6); 
BgL_auxz00_951 = 
(long)CINT(BgL_obj1z00_5); 
return 
(BgL_auxz00_951==BgL_auxz00_953);}  else 
{ /* ./Ieee/equiv.scm 95 */
return ((bool_t)0);} }  else 
{ /* ./Ieee/equiv.scm 94 */
if(
SYMBOLP(BgL_obj1z00_5))
{ /* ./Ieee/equiv.scm 98 */
return ((bool_t)0);}  else 
{ /* ./Ieee/equiv.scm 98 */
if(
PAIRP(BgL_obj1z00_5))
{ /* ./Ieee/equiv.scm 100 */
if(
PAIRP(BgL_obj2z00_6))
{ /* ./Ieee/equiv.scm 101 */
if(
BGl_equalzf3zf3zz__r4_equivalence_6_2z00(
CAR(BgL_obj1z00_5), 
CAR(BgL_obj2z00_6)))
{ 
obj_t BgL_obj2z00_968;obj_t BgL_obj1z00_966;
BgL_obj1z00_966 = 
CDR(BgL_obj1z00_5); 
BgL_obj2z00_968 = 
CDR(BgL_obj2z00_6); 
BgL_obj2z00_6 = BgL_obj2z00_968; 
BgL_obj1z00_5 = BgL_obj1z00_966; 
goto BGl_equalzf3zf3zz__r4_equivalence_6_2z00;}  else 
{ /* ./Ieee/equiv.scm 101 */
return ((bool_t)0);} }  else 
{ /* ./Ieee/equiv.scm 101 */
return ((bool_t)0);} }  else 
{ /* ./Ieee/equiv.scm 100 */
if(
VECTORP(BgL_obj1z00_5))
{ /* ./Ieee/equiv.scm 103 */
{ /* ./Ieee/equiv.scm 104 */
int BgL_lobj1z00_484;
BgL_lobj1z00_484 = 
VECTOR_LENGTH(BgL_obj1z00_5); 
if(
VECTORP(BgL_obj2z00_6))
{ /* ./Ieee/equiv.scm 106 */
bool_t BgL__andtest_1014z00_486;
{ /* ./Ieee/equiv.scm 106 */
int BgL_arg1105z00_497;
BgL_arg1105z00_497 = 
VECTOR_LENGTH(BgL_obj2z00_6); 
{ /* ./Ieee/equiv.scm 106 */
long BgL_auxz00_978;long BgL_auxz00_976;
BgL_auxz00_978 = 
(long)(BgL_lobj1z00_484); 
BgL_auxz00_976 = 
(long)(BgL_arg1105z00_497); 
BgL__andtest_1014z00_486 = 
(BgL_auxz00_976==BgL_auxz00_978); } } 
if(BgL__andtest_1014z00_486)
{ /* ./Ieee/equiv.scm 107 */
bool_t BgL__andtest_1015z00_487;
{ /* ./Ieee/equiv.scm 107 */
int BgL_arg1099z00_495;int BgL_arg1100z00_496;
BgL_arg1099z00_495 = 
VECTOR_TAG(BgL_obj1z00_5); 
BgL_arg1100z00_496 = 
VECTOR_TAG(BgL_obj2z00_6); 
{ /* ./Ieee/equiv.scm 107 */
long BgL_auxz00_986;long BgL_auxz00_984;
BgL_auxz00_986 = 
(long)(BgL_arg1100z00_496); 
BgL_auxz00_984 = 
(long)(BgL_arg1099z00_495); 
BgL__andtest_1015z00_487 = 
(BgL_auxz00_984==BgL_auxz00_986); } } 
if(BgL__andtest_1015z00_487)
{ 
long BgL_iz00_488;
BgL_iz00_488 = ((long)0); 
BgL_testz00_489:
{ /* ./Ieee/equiv.scm 109 */
bool_t BgL__ortest_1016z00_490;
{ /* ./Ieee/equiv.scm 109 */
long BgL_auxz00_990;
BgL_auxz00_990 = 
(long)(BgL_lobj1z00_484); 
BgL__ortest_1016z00_490 = 
(BgL_iz00_488==BgL_auxz00_990); } 
if(BgL__ortest_1016z00_490)
{ /* ./Ieee/equiv.scm 109 */
return BgL__ortest_1016z00_490;}  else 
{ /* ./Ieee/equiv.scm 110 */
bool_t BgL_testz00_994;
{ /* ./Ieee/equiv.scm 110 */
obj_t BgL_auxz00_999;obj_t BgL_auxz00_995;
{ 
int BgL_auxz00_1000;
BgL_auxz00_1000 = 
(int)(BgL_iz00_488); 
BgL_auxz00_999 = 
VECTOR_REF(BgL_obj2z00_6,BgL_auxz00_1000); } 
{ 
int BgL_auxz00_996;
BgL_auxz00_996 = 
(int)(BgL_iz00_488); 
BgL_auxz00_995 = 
VECTOR_REF(BgL_obj1z00_5,BgL_auxz00_996); } 
BgL_testz00_994 = 
BGl_equalzf3zf3zz__r4_equivalence_6_2z00(BgL_auxz00_995, BgL_auxz00_999); } 
if(BgL_testz00_994)
{ 
long BgL_iz00_1004;
BgL_iz00_1004 = 
(BgL_iz00_488+((long)1)); 
BgL_iz00_488 = BgL_iz00_1004; 
goto BgL_testz00_489;}  else 
{ /* ./Ieee/equiv.scm 110 */
return ((bool_t)0);} } } }  else 
{ /* ./Ieee/equiv.scm 107 */
return ((bool_t)0);} }  else 
{ /* ./Ieee/equiv.scm 106 */
return ((bool_t)0);} }  else 
{ /* ./Ieee/equiv.scm 105 */
return ((bool_t)0);} } }  else 
{ /* ./Ieee/equiv.scm 103 */
if(
STRINGP(BgL_obj1z00_5))
{ /* ./Ieee/equiv.scm 113 */
if(
STRINGP(BgL_obj2z00_6))
{ /* ./Ieee/equiv.scm 114 */
return 
bigloo_strcmp(BgL_obj1z00_5, BgL_obj2z00_6);}  else 
{ /* ./Ieee/equiv.scm 114 */
return ((bool_t)0);} }  else 
{ /* ./Ieee/equiv.scm 113 */
if(
REALP(BgL_obj1z00_5))
{ /* ./Ieee/equiv.scm 115 */
if(
REALP(BgL_obj2z00_6))
{ /* ./Ieee/equiv.scm 117 */
double BgL_auxz00_1017;double BgL_auxz00_1015;
BgL_auxz00_1017 = 
REAL_TO_DOUBLE(BgL_obj2z00_6); 
BgL_auxz00_1015 = 
REAL_TO_DOUBLE(BgL_obj1z00_5); 
return 
(BgL_auxz00_1015==BgL_auxz00_1017);}  else 
{ /* ./Ieee/equiv.scm 116 */
return ((bool_t)0);} }  else 
{ /* ./Ieee/equiv.scm 115 */
if(
STRUCTP(BgL_obj1z00_5))
{ /* ./Ieee/equiv.scm 118 */
{ /* ./Ieee/equiv.scm 119 */
int BgL_lobj1z00_503;
BgL_lobj1z00_503 = 
STRUCT_LENGTH(BgL_obj1z00_5); 
if(
STRUCTP(BgL_obj2z00_6))
{ /* ./Ieee/equiv.scm 121 */
bool_t BgL_testz00_1025;
{ /* ./Ieee/equiv.scm 121 */
long BgL_auxz00_1030;long BgL_auxz00_1026;
BgL_auxz00_1030 = 
(long)(BgL_lobj1z00_503); 
{ /* ./Ieee/equiv.scm 121 */
int BgL_auxz00_1027;
BgL_auxz00_1027 = 
STRUCT_LENGTH(BgL_obj2z00_6); 
BgL_auxz00_1026 = 
(long)(BgL_auxz00_1027); } 
BgL_testz00_1025 = 
(BgL_auxz00_1026==BgL_auxz00_1030); } 
if(BgL_testz00_1025)
{ 
long BgL_iz00_506;
BgL_iz00_506 = ((long)0); 
BgL_testz00_507:
{ /* ./Ieee/equiv.scm 123 */
bool_t BgL__ortest_1022z00_508;
{ /* ./Ieee/equiv.scm 123 */
long BgL_auxz00_1033;
BgL_auxz00_1033 = 
(long)(BgL_lobj1z00_503); 
BgL__ortest_1022z00_508 = 
(BgL_iz00_506==BgL_auxz00_1033); } 
if(BgL__ortest_1022z00_508)
{ /* ./Ieee/equiv.scm 123 */
return BgL__ortest_1022z00_508;}  else 
{ /* ./Ieee/equiv.scm 124 */
bool_t BgL_testz00_1037;
{ /* ./Ieee/equiv.scm 124 */
obj_t BgL_auxz00_1042;obj_t BgL_auxz00_1038;
{ /* ./Ieee/equiv.scm 124 */
int BgL_auxz00_1043;
BgL_auxz00_1043 = 
(int)(BgL_iz00_506); 
BgL_auxz00_1042 = 
STRUCT_REF(BgL_obj2z00_6, BgL_auxz00_1043); } 
{ /* ./Ieee/equiv.scm 124 */
int BgL_auxz00_1039;
BgL_auxz00_1039 = 
(int)(BgL_iz00_506); 
BgL_auxz00_1038 = 
STRUCT_REF(BgL_obj1z00_5, BgL_auxz00_1039); } 
BgL_testz00_1037 = 
BGl_equalzf3zf3zz__r4_equivalence_6_2z00(BgL_auxz00_1038, BgL_auxz00_1042); } 
if(BgL_testz00_1037)
{ 
long BgL_iz00_1047;
BgL_iz00_1047 = 
(BgL_iz00_506+((long)1)); 
BgL_iz00_506 = BgL_iz00_1047; 
goto BgL_testz00_507;}  else 
{ /* ./Ieee/equiv.scm 124 */
return ((bool_t)0);} } } }  else 
{ /* ./Ieee/equiv.scm 121 */
return ((bool_t)0);} }  else 
{ /* ./Ieee/equiv.scm 120 */
return ((bool_t)0);} } }  else 
{ /* ./Ieee/equiv.scm 118 */
if(
CELLP(BgL_obj1z00_5))
{ /* ./Ieee/equiv.scm 126 */
if(
CELLP(BgL_obj2z00_6))
{ 
obj_t BgL_obj2z00_1055;obj_t BgL_obj1z00_1053;
BgL_obj1z00_1053 = 
CELL_REF(BgL_obj1z00_5); 
BgL_obj2z00_1055 = 
CELL_REF(BgL_obj2z00_6); 
BgL_obj2z00_6 = BgL_obj2z00_1055; 
BgL_obj1z00_5 = BgL_obj1z00_1053; 
goto BGl_equalzf3zf3zz__r4_equivalence_6_2z00;}  else 
{ /* ./Ieee/equiv.scm 127 */
return ((bool_t)0);} }  else 
{ /* ./Ieee/equiv.scm 129 */
bool_t BgL_test1143z00_518;
if(BgL_test1062z00_473)
{ /* ./Ieee/equiv.scm 129 */
BgL_test1143z00_518 = ((bool_t)1); }  else 
{ /* ./Ieee/equiv.scm 129 */
BgL_test1143z00_518 = 
REALP(BgL_obj1z00_5); } 
if(BgL_test1143z00_518)
{ /* ./Ieee/equiv.scm 129 */
{ /* ./Ieee/equiv.scm 130 */
bool_t BgL_testz00_1060;
if(
INTEGERP(BgL_obj2z00_6))
{ /* ./Ieee/equiv.scm 130 */
BgL_testz00_1060 = ((bool_t)1)
; }  else 
{ /* ./Ieee/equiv.scm 130 */
BgL_testz00_1060 = 
REALP(BgL_obj2z00_6)
; } 
if(BgL_testz00_1060)
{ /* ./Ieee/equiv.scm 130 */
return 
BGl_2zd3zd3zz__r4_numbers_6_5z00(BgL_obj1z00_5, BgL_obj2z00_6);}  else 
{ /* ./Ieee/equiv.scm 130 */
return ((bool_t)0);} } }  else 
{ /* ./Ieee/equiv.scm 132 */
bool_t BgL_test1146z00_520;
BgL_test1146z00_520 = 
BGL_OBJECTP(BgL_obj1z00_5); 
if(BgL_test1146z00_520)
{ /* ./Ieee/equiv.scm 132 */
{ /* ./Ieee/equiv.scm 133 */
bool_t BgL__andtest_1026z00_521;
BgL__andtest_1026z00_521 = 
BGL_OBJECTP(BgL_obj2z00_6); 
if(BgL__andtest_1026z00_521)
{ /* ./Ieee/equiv.scm 133 */
return 
BGl_objectzd2equalzf3z21zz__objectz00(
(BgL_objectz00_bglt)(BgL_obj1z00_5), 
(BgL_objectz00_bglt)(BgL_obj2z00_6));}  else 
{ /* ./Ieee/equiv.scm 133 */
return ((bool_t)0);} } }  else 
{ /* ./Ieee/equiv.scm 132 */
if(
UCS2_STRINGP(BgL_obj1z00_5))
{ /* ./Ieee/equiv.scm 135 */
if(
UCS2_STRINGP(BgL_obj2z00_6))
{ /* ./Ieee/equiv.scm 136 */
return 
ucs2_strcmp(BgL_obj1z00_5, BgL_obj2z00_6);}  else 
{ /* ./Ieee/equiv.scm 136 */
return ((bool_t)0);} }  else 
{ /* ./Ieee/equiv.scm 135 */
if(
CUSTOMP(BgL_obj1z00_5))
{ /* ./Ieee/equiv.scm 137 */
if(
CUSTOMP(BgL_obj2z00_6))
{ /* ./Ieee/equiv.scm 138 */
return 
CUSTOM_CMP(BgL_obj1z00_5, BgL_obj2z00_6);}  else 
{ /* ./Ieee/equiv.scm 138 */
return ((bool_t)0);} }  else 
{ /* ./Ieee/equiv.scm 137 */
if(
FOREIGNP(BgL_obj1z00_5))
{ /* ./Ieee/equiv.scm 139 */
if(
FOREIGNP(BgL_obj2z00_6))
{ /* ./Ieee/equiv.scm 140 */
return 
FOREIGN_EQP(BgL_obj1z00_5, BgL_obj2z00_6);}  else 
{ /* ./Ieee/equiv.scm 140 */
return ((bool_t)0);} }  else 
{ /* ./Ieee/equiv.scm 139 */
if(
UCS2P(BgL_obj1z00_5))
{ /* ./Ieee/equiv.scm 142 */
if(
UCS2P(BgL_obj2z00_6))
{ /* ./Ieee/equiv.scm 143 */
ucs2_t BgL_auxz00_1093;ucs2_t BgL_auxz00_1091;
BgL_auxz00_1093 = 
CUCS2(BgL_obj2z00_6); 
BgL_auxz00_1091 = 
CUCS2(BgL_obj1z00_5); 
return 
(BgL_auxz00_1091==BgL_auxz00_1093);}  else 
{ /* ./Ieee/equiv.scm 143 */
return ((bool_t)0);} }  else 
{ /* ./Ieee/equiv.scm 142 */
if(
ELONGP(BgL_obj1z00_5))
{ /* ./Ieee/equiv.scm 144 */
if(
ELONGP(BgL_obj2z00_6))
{ /* ./Ieee/equiv.scm 145 */
bool_t BgL_res2039z00_849;
{ /* ./Ieee/equiv.scm 145 */
long BgL_arg1729z00_847;long BgL_arg1731z00_848;
BgL_arg1729z00_847 = 
BELONG_TO_LONG(BgL_obj1z00_5); 
BgL_arg1731z00_848 = 
BELONG_TO_LONG(BgL_obj2z00_6); 
BgL_res2039z00_849 = 
(BgL_arg1729z00_847==BgL_arg1731z00_848); } 
return BgL_res2039z00_849;}  else 
{ /* ./Ieee/equiv.scm 145 */
return ((bool_t)0);} }  else 
{ /* ./Ieee/equiv.scm 144 */
if(
LLONGP(BgL_obj1z00_5))
{ /* ./Ieee/equiv.scm 146 */
if(
LLONGP(BgL_obj2z00_6))
{ /* ./Ieee/equiv.scm 147 */
bool_t BgL_res2040z00_856;
{ /* ./Ieee/equiv.scm 147 */
BGL_LONGLONG_T BgL_auxz00_1109;BGL_LONGLONG_T BgL_auxz00_1107;
BgL_auxz00_1109 = 
BLLONG_TO_LLONG(BgL_obj2z00_6); 
BgL_auxz00_1107 = 
BLLONG_TO_LLONG(BgL_obj1z00_5); 
BgL_res2040z00_856 = 
(BgL_auxz00_1107==BgL_auxz00_1109); } 
return BgL_res2040z00_856;}  else 
{ /* ./Ieee/equiv.scm 147 */
return ((bool_t)0);} }  else 
{ /* ./Ieee/equiv.scm 148 */
bool_t BgL_test1167z00_534;
BgL_test1167z00_534 = 
BGL_DATEP(BgL_obj1z00_5); 
if(BgL_test1167z00_534)
{ /* ./Ieee/equiv.scm 148 */
{ /* ./Ieee/equiv.scm 149 */
bool_t BgL__andtest_1033z00_535;
BgL__andtest_1033z00_535 = 
BGL_DATEP(BgL_obj2z00_6); 
if(BgL__andtest_1033z00_535)
{ /* ./Ieee/equiv.scm 149 */
long BgL_auxz00_1118;long BgL_auxz00_1116;
BgL_auxz00_1118 = 
bgl_date_to_seconds(BgL_obj2z00_6); 
BgL_auxz00_1116 = 
bgl_date_to_seconds(BgL_obj1z00_5); 
return 
(BgL_auxz00_1116==BgL_auxz00_1118);}  else 
{ /* ./Ieee/equiv.scm 149 */
return ((bool_t)0);} } }  else 
{ /* ./Ieee/equiv.scm 148 */
return ((bool_t)0);} } } } } } } } } } } } } } } } } } } 
}



/* _equal? */
obj_t BGl__equalzf3zf3zz__r4_equivalence_6_2z00(obj_t BgL_envz00_903, obj_t BgL_obj1z00_904, obj_t BgL_obj2z00_905)
{ AN_OBJECT;
{ /* ./Ieee/equiv.scm 90 */
{ /* ./Ieee/equiv.scm 92 */
bool_t BgL_auxz00_1121;
BgL_auxz00_1121 = 
BGl_equalzf3zf3zz__r4_equivalence_6_2z00(BgL_obj1z00_904, BgL_obj2z00_905); 
return 
BBOOL(BgL_auxz00_1121);} } 
}



/* method-init */
obj_t BGl_methodzd2initzd2zz__r4_equivalence_6_2z00()
{ AN_OBJECT;
{ /* ./Ieee/equiv.scm 14 */
return BUNSPEC;} 
}



/* imported-modules-init */
obj_t BGl_importedzd2moduleszd2initz00zz__r4_equivalence_6_2z00()
{ AN_OBJECT;
{ /* ./Ieee/equiv.scm 14 */
return 
BGl_modulezd2initializa7ationz75zz__errorz00(((long)11084), "__r4_equivalence_6_2");} 
}

